BodyDispatchVehicleBuilder class

Properties

filter VehicleCapabilityModelBuilder
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toLocation CoordinateModelBuilder
getter/setter pair

Methods

build() BodyDispatchVehicle
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(BodyDispatchVehicle other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(BodyDispatchVehicleBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited