ReferenceFrameModel class abstract

ReferenceFrameModel

Properties:

Annotations
  • @BuiltValue.new()

Constructors

ReferenceFrameModel([void updates(ReferenceFrameModelBuilder b)])
factory

Properties

enuPose PoseModel
no setter
frame String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(ReferenceFrameModelBuilder)) ReferenceFrameModel
Rebuilds the instance.
inherited
toBuilder() ReferenceFrameModelBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<ReferenceFrameModel>
no setter