SiteInfoModel class abstract

SiteInfoModel

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SiteInfoModel([void updates(SiteInfoModelBuilder b)])
factory

Properties

address String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SiteInfoModelBuilder)) SiteInfoModel
Rebuilds the instance.
inherited
toBuilder() SiteInfoModelBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SiteInfoModel>
no setter