SpeedModel class abstract

SpeedModel

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SpeedModel([void updates(SpeedModelBuilder b)])
factory

Properties

accuracyMph num?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedMph num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SpeedModelBuilder)) SpeedModel
Rebuilds the instance.
inherited
toBuilder() SpeedModelBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SpeedModel>
no setter