VehicleModel class abstract

Annotations
  • @BuiltValue.new()

Constructors

VehicleModel([void updates(VehicleModelBuilder b)])
factory

Properties

desc String?
no setter
fqdn String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
imageMediumUrl String
no setter
imageSmallUrl String
no setter
odometry OdometryModel?
no setter
parameters VehicleParameters
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serialNumber String
no setter
status VehicleStatusModel?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(VehicleModelBuilder)) VehicleModel
Rebuilds the instance.
inherited
toBuilder() VehicleModelBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<VehicleModel>
no setter