AutonomyStateModel class abstract
AutonomyStateModel
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- AutonomyStateModel([void updates(AutonomyStateModelBuilder b)])
-
factory
Properties
- controlMode → AutonomyControlModeEnum
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- interventionRequest → InterventionRequestEnum
-
no setter
- isOperational → bool
-
no setter
- motionState → MotionStateEnum
-
no setter
- onEmergencyResponse → bool
-
no setter
- pathUuid → String
-
no setter
- perceptionState → PerceptionStateEnum
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(AutonomyStateModelBuilder)) → AutonomyStateModel -
Rebuilds the instance.
inherited
-
toBuilder(
) → AutonomyStateModelBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
AutonomyStateModel> -
no setter