RoomModel class abstract
RoomModel
Properties:
- Annotations
-
- @BuiltValue.new()
Constructors
- RoomModel([void updates(RoomModelBuilder b)])
-
factory
Properties
- activeRecording → bool?
-
no setter
- creationTime → int?
-
no setter
- creationTimeMs → int?
-
no setter
- departureTimeout → int?
-
no setter
- emptyTimeout → int?
-
no setter
-
enabledCodecs
→ BuiltList<
CodecModel> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxParticipants → int?
-
no setter
- metadata → String?
-
no setter
- name → String?
-
no setter
- numParticipants → int?
-
no setter
- numPublishers → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sid → String?
-
no setter
- turnPassword → String?
-
no setter
- version → TimedVersionModel?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(RoomModelBuilder)) → RoomModel -
Rebuilds the instance.
inherited
-
toBuilder(
) → RoomModelBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
RoomModel> -
no setter