RouteObjectiveModel class abstract
RouteObjectiveModel
Properties:
- id
- name
- type
- chartId
- routeId
- constraints
- lastStatus
- status - Latest-first status list
- laps
- Annotations
-
- @BuiltValue.new()
Constructors
- RouteObjectiveModel([void updates(RouteObjectiveModelBuilder b)])
-
factory
Properties
- chartId → String
-
no setter
- constraints → SpeedConstraintsModel
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- laps → int?
-
no setter
- lastStatus → ObjectiveStatusModel?
-
no setter
- name → String
-
no setter
- routeId → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ BuiltList<
ObjectiveStatusModel> ? -
Latest-first status list
no setter
- type → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(RouteObjectiveModelBuilder)) → RouteObjectiveModel -
Rebuilds the instance.
inherited
-
toBuilder(
) → RouteObjectiveModelBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
RouteObjectiveModel> -
no setter